==> genometools-1.0.5.tar.gz: genometools-1.0.5/src/libgtext/alignment.h <==
/*
  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ALIGNMENT_H
#define ALIGNMENT_H

#include <stdio.h>
#include "libgtcore/env.h"

/* the Alignment class (an Alignment object has to be contructed backwards) */
typedef struct Alignment Alignment;

Alignment*    alignment_new(Env*);
Alignment*    alignment_new_with_seqs(const char *u, unsigned long ulen,
                                      const char *v, unsigned long vlen, Env*);
void          alignment_set_seqs(Alignment*, const char *u, unsigned long ulen,
                                 const char *v, unsigned long vlen);
void          alignment_add_replacement(Alignment*, Env*);
void          alignment_add_deletion(Alignment*, Env*);
void          alignment_add_insertion(Alignment*, Env*);
void          alignment_remove_last(Alignment*); /* undo last add operation */
unsigned long alignment_eval(const Alignment*); /* returns unit cost */
void          alignment_show(const Alignment*, FILE*);
void          alignment_show_multieop_list(const Alignment*, FILE*);
int           alignment_unit_test(Env*);
void          alignment_delete(Alignment*, Env*);

#endif

==> genometools-1.1.1.tar.gz: genometools-1.1.1/src/libgtext/alignment.h <==
/*
  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ALIGNMENT_H
#define ALIGNMENT_H

#include <stdio.h>
#include "libgtcore/error.h"

/* the Alignment class (an Alignment object has to be contructed backwards) */
typedef struct Alignment Alignment;

Alignment*    alignment_new(void);
Alignment*    alignment_new_with_seqs(const char *u, unsigned long ulen,
                                      const char *v, unsigned long vlen);
void          alignment_set_seqs(Alignment*, const char *u, unsigned long ulen,
                                 const char *v, unsigned long vlen);
void          alignment_add_replacement(Alignment*);
void          alignment_add_deletion(Alignment*);
void          alignment_add_insertion(Alignment*);
void          alignment_remove_last(Alignment*); /* undo last add operation */
unsigned long alignment_eval(const Alignment*); /* returns unit cost */
void          alignment_show(const Alignment*, FILE*);
void          alignment_show_multieop_list(const Alignment*, FILE*);
int           alignment_unit_test(Error*);
void          alignment_delete(Alignment*);

#endif
